@@ -1,6 +1,3 @@
-import os
-import tempfile
-
 from pipeline.conf import settings
 from pipeline.compilers import SubProcessCompiler
 
@@ -11,20 +8,11 @@ class LessCompiler(SubProcessCompiler):
     def match_file(self, filename):
         return filename.endswith('.less')
 
-    def compile_file(self, content):
-        in_file, in_filename = tempfile.mkstemp()
-        in_file = os.fdopen(in_file, 'w+b')
-        in_file.write(content)
-        in_file.flush()
-
+    def compile_file(self, content, path):
         command = '%s %s %s' % (
             settings.PIPELINE_LESS_BINARY,
             settings.PIPELINE_LESS_ARGUMENTS,
-            in_filename
+            path
         )
-        content = self.execute_command(command, content)
-
-        in_file.close()
-        os.remove(in_filename)
-
+        content = self.execute_command(command)
         return content
